package cn.pluss.platform.mapper;

import java.util.List;
import java.util.Map;
import org.apache.ibatis.annotations.Mapper;
import cn.pluss.platform.entity.NewArea;

@Mapper
public interface NewAreaMapper {

    public NewArea queryNewArea(NewArea newArea);

    public List<NewArea> queryNewAreaList(NewArea newArea);

    public void saveNewArea(NewArea newArea);

    public void updateNewArea(NewArea newArea);

    public void deleteNewArea(NewArea newArea);

    public List<NewArea> queryNewAreaPage(Map map);

    public Integer queryNewAreaPageCount(Map map);

    public void saveNewAreaBatch(List<NewArea>  newAreaList);
}

